python-chi
==========

.. figure:: https://github.com/ChameleonCloud/python-chi/workflows/Unit%20tests/badge.svg
   :target: https://github.com/ChameleonCloud/python-chi/actions?query=workflow%3A%22Unit+tests%22

``python-chi`` is a Python library that can help you interact with the
`Chameleon testbed <https://www.chameleoncloud.org>`_ to improve your
workflows with automation. It additionally pairs well with environments like
Jupyter Notebooks.

* `Documentation <https://python-chi.readthedocs.io>`_
* `Contributing guide <./DEVELOPMENT.rst>`_
